@@ -1,7 +1,7 @@
 /*********************************************************************
  * NAN - Native Abstractions for Node.js
  *
- * Copyright (c) 2016 NAN contributors
+ * Copyright (c) 2018 NAN contributors
  *
  * MIT License <https://github.com/nodejs/nan/blob/master/LICENSE.md>
  ********************************************************************/
@@ -14,7 +14,7 @@ using namespace Nan;  // NOLINT(build/namespaces)
 NAN_MODULE_INIT(Init) {
   Set(target
     , New<v8::String>("r").ToLocalChecked()
-    , New<v8::FunctionTemplate>(ReturnString)->GetFunction()
+    , GetFunction(New<v8::FunctionTemplate>(ReturnString)).ToLocalChecked()
   );
 }
 
