@@ -1,7 +1,7 @@
 /*********************************************************************
  * NAN - Native Abstractions for Node.js
  *
- * Copyright (c) 2016 NAN contributors
+ * Copyright (c) 2018 NAN contributors
  *
  * MIT License <https://github.com/nodejs/nan/blob/master/LICENSE.md>
  ********************************************************************/
@@ -47,7 +47,7 @@ assertType(U value) {
 
 bool
 stringMatches(Local<Value> value, const char * match) {
-  String::Utf8Value v(value);
+  Nan::Utf8String v(value);
   return std::string(*v) == std::string(match);
 }
 
